diff --git a/core/lib/Drupal/Core/Controller/ControllerBase.php b/core/lib/Drupal/Core/Controller/ControllerBase.php
index 68c2655a57..5763a7dc14 100644
--- a/core/lib/Drupal/Core/Controller/ControllerBase.php
+++ b/core/lib/Drupal/Core/Controller/ControllerBase.php
@@ -129,6 +129,7 @@ public static function create(ContainerInterface $container) {
    *   instead.
    */
   protected function entityManager() {
+    @trigger_error('ControllerBase::getEntityManager() is deprecated in Drupal 8.7.0 and will be removed before Drupal 9.0.0. Use ::getEntityTypeManager() instead. See https://www.drupal.org/node/2549139.', E_USER_DEPRECATED);
     if (!$this->entityManager) {
       $this->entityManager = $this->container()->get('entity.manager');
     }
diff --git a/core/lib/Drupal/Core/Entity/Controller/EntityListController.php b/core/lib/Drupal/Core/Entity/Controller/EntityListController.php
index ee354677c6..e0b12641ce 100644
--- a/core/lib/Drupal/Core/Entity/Controller/EntityListController.php
+++ b/core/lib/Drupal/Core/Entity/Controller/EntityListController.php
@@ -20,7 +20,7 @@ class EntityListController extends ControllerBase {
    *   \Drupal\Core\Render\RendererInterface::render().
    */
   public function listing($entity_type) {
-    return $this->entityManager()->getListBuilder($entity_type)->render();
+    return $this->entityTypeManager()->getListBuilder($entity_type)->render();
   }
 
 }
diff --git a/core/modules/aggregator/src/Controller/AggregatorController.php b/core/modules/aggregator/src/Controller/AggregatorController.php
index 47827b904a..b6d49478a4 100644
--- a/core/modules/aggregator/src/Controller/AggregatorController.php
+++ b/core/modules/aggregator/src/Controller/AggregatorController.php
@@ -48,7 +48,7 @@ public static function create(ContainerInterface $container) {
    *   \Drupal\Core\Render\RendererInterface::render().
    */
   public function feedAdd() {
-    $feed = $this->entityManager()->getStorage('aggregator_feed')->create();
+    $feed = $this->entityTypeManager()->getStorage('aggregator_feed')->create();
     return $this->entityFormBuilder()->getForm($feed);
   }
 
@@ -71,7 +71,7 @@ protected function buildPageList(array $items, $feed_source = '') {
     ];
     $build['feed_source'] = is_array($feed_source) ? $feed_source : ['#markup' => $feed_source];
     if ($items) {
-      $build['items'] = $this->entityManager()->getViewBuilder('aggregator_item')
+      $build['items'] = $this->entityTypeManager()->getViewBuilder('aggregator_item')
         ->viewMultiple($items, 'default');
       $build['pager'] = ['#type' => 'pager'];
     }
@@ -106,8 +106,8 @@ public function feedRefresh(FeedInterface $aggregator_feed) {
    *   \Drupal\Core\Render\RendererInterface::render().
    */
   public function adminOverview() {
-    $entity_manager = $this->entityManager();
-    $feeds = $entity_manager->getStorage('aggregator_feed')
+    $entity_type_manager = $this->entityTypeManager();
+    $feeds = $entity_type_manager->getStorage('aggregator_feed')
       ->loadMultiple();
 
     $header = [$this->t('Title'), $this->t('Items'), $this->t('Last update'), $this->t('Next update'), $this->t('Operations')];
@@ -116,7 +116,7 @@ public function adminOverview() {
     foreach ($feeds as $feed) {
       $row = [];
       $row[] = $feed->link();
-      $row[] = $this->formatPlural($entity_manager->getStorage('aggregator_item')->getItemCount($feed), '1 item', '@count items');
+      $row[] = $this->formatPlural($entity_type_manager->getStorage('aggregator_item')->getItemCount($feed), '1 item', '@count items');
       $last_checked = $feed->getLastCheckedTime();
       $refresh_rate = $feed->getRefreshRate();
 
@@ -173,7 +173,7 @@ public function adminOverview() {
    *   The rendered list of items for the feed.
    */
   public function pageLast() {
-    $items = $this->entityManager()->getStorage('aggregator_item')->loadAll(20);
+    $items = $this->entityTypeManager()->getStorage('aggregator_item')->loadAll(20);
     $build = $this->buildPageList($items);
     $build['#attached']['feed'][] = ['aggregator/rss', $this->config('system.site')->get('name') . ' ' . $this->t('aggregator')];
     return $build;
diff --git a/core/modules/block/src/Controller/BlockAddController.php b/core/modules/block/src/Controller/BlockAddController.php
index 973a85995e..1507f61d8a 100644
--- a/core/modules/block/src/Controller/BlockAddController.php
+++ b/core/modules/block/src/Controller/BlockAddController.php
@@ -22,7 +22,7 @@ class BlockAddController extends ControllerBase {
    */
   public function blockAddConfigureForm($plugin_id, $theme) {
     // Create a block entity.
-    $entity = $this->entityManager()->getStorage('block')->create(['plugin' => $plugin_id, 'theme' => $theme]);
+    $entity = $this->entityTypeManager()->getStorage('block')->create(['plugin' => $plugin_id, 'theme' => $theme]);
 
     return $this->entityFormBuilder()->getForm($entity);
   }
diff --git a/core/modules/block/src/Controller/BlockListController.php b/core/modules/block/src/Controller/BlockListController.php
index d88d1f458c..9a1503153e 100644
--- a/core/modules/block/src/Controller/BlockListController.php
+++ b/core/modules/block/src/Controller/BlockListController.php
@@ -57,7 +57,7 @@ public function listing($theme = NULL, Request $request = NULL) {
       throw new NotFoundHttpException();
     }
 
-    return $this->entityManager()->getListBuilder('block')->render($theme, $request);
+    return $this->entityTypeManager()->getListBuilder('block')->render($theme, $request);
   }
 
 }
diff --git a/core/modules/book/src/Controller/BookController.php b/core/modules/book/src/Controller/BookController.php
index fa34d92711..998fa16c5b 100644
--- a/core/modules/book/src/Controller/BookController.php
+++ b/core/modules/book/src/Controller/BookController.php
@@ -122,7 +122,7 @@ public function bookRender() {
       '#theme' => 'item_list',
       '#items' => $book_list,
       '#cache' => [
-        'tags' => \Drupal::entityManager()->getDefinition('node')->getListCacheTags(),
+        'tags' => $this->entityTypeManager()->getDefinition('node')->getListCacheTags(),
       ],
     ];
   }
diff --git a/core/modules/comment/src/Controller/CommentController.php b/core/modules/comment/src/Controller/CommentController.php
index ad821e333d..1dd90e24cb 100644
--- a/core/modules/comment/src/Controller/CommentController.php
+++ b/core/modules/comment/src/Controller/CommentController.php
@@ -8,8 +8,10 @@
 use Drupal\Core\Access\AccessResult;
 use Drupal\Core\Cache\CacheableResponseInterface;
 use Drupal\Core\Controller\ControllerBase;
+use Drupal\Core\Entity\EntityFieldManagerInterface;
 use Drupal\Core\Entity\EntityInterface;
-use Drupal\Core\Entity\EntityManagerInterface;
+use Drupal\Core\Entity\EntityRepositoryInterface;
+use Drupal\Core\Entity\EntityTypeManagerInterface;
 use Symfony\Component\DependencyInjection\ContainerInterface;
 use Symfony\Component\HttpFoundation\JsonResponse;
 use Symfony\Component\HttpFoundation\RedirectResponse;
@@ -40,11 +42,18 @@ class CommentController extends ControllerBase {
   protected $commentManager;
 
   /**
-   * The entity manager.
+   * The entity field manager.
    *
-   * @var \Drupal\Core\Entity\EntityStorageInterface
+   * @var \Drupal\Core\Entity\EntityFieldManagerInterface
    */
-  protected $entityManager;
+  protected $entityFieldManager;
+
+  /**
+   * The entity repository.
+   *
+   * @var Drupal\Core\Entity\EntityRepositoryInterface
+   */
+  protected $entityRepository;
 
   /**
    * Constructs a CommentController object.
@@ -53,13 +62,19 @@ class CommentController extends ControllerBase {
    *   HTTP kernel to handle requests.
    * @param \Drupal\comment\CommentManagerInterface $comment_manager
    *   The comment manager service.
-   * @param \Drupal\Core\Entity\EntityManagerInterface $entity_manager
-   *   The entity manager service.
+   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
+   *   The entity type manager service.
+   * @param \Drupal\Core\Entity\EntityFieldManagerInterface $entity_field_manger
+   *   The entity field manager service.
+   * @param \Drupal\Core\Entity\EntityRepositoryInterface $entity_repository
+   *   The entity repository service.
    */
-  public function __construct(HttpKernelInterface $http_kernel, CommentManagerInterface $comment_manager, EntityManagerInterface $entity_manager) {
+  public function __construct(HttpKernelInterface $http_kernel, CommentManagerInterface $comment_manager, EntityTypeManagerInterface $entity_type_manager, EntityFieldManagerInterface $entity_field_manger, EntityRepositoryInterface $entity_repository) {
     $this->httpKernel = $http_kernel;
     $this->commentManager = $comment_manager;
-    $this->entityManager = $entity_manager;
+    $this->entityTypeManager = $entity_type_manager;
+    $this->entityFieldManager = $entity_field_manger;
+    $this->entityRepository = $entity_repository;
   }
 
   /**
@@ -69,7 +84,9 @@ public static function create(ContainerInterface $container) {
     return new static(
       $container->get('http_kernel'),
       $container->get('comment.manager'),
-      $container->get('entity.manager')
+      $container->get('entity_type.manager'),
+      $container->get('entity_field.manager'),
+      $container->get('entity.repository')
     );
   }
 
@@ -119,10 +136,10 @@ public function commentPermalink(Request $request, CommentInterface $comment) {
       if (!$entity->access('view')) {
         throw new AccessDeniedHttpException();
       }
-      $field_definition = $this->entityManager()->getFieldDefinitions($entity->getEntityTypeId(), $entity->bundle())[$comment->getFieldName()];
+      $field_definition = $this->entityFieldManager->getFieldDefinitions($entity->getEntityTypeId(), $entity->bundle())[$comment->getFieldName()];
 
       // Find the current display page for this comment.
-      $page = $this->entityManager()->getStorage('comment')->getDisplayOrdinal($comment, $field_definition->getSetting('default_mode'), $field_definition->getSetting('per_page'));
+      $page = $this->entityTypeManager()->getStorage('comment')->getDisplayOrdinal($comment, $field_definition->getSetting('default_mode'), $field_definition->getSetting('per_page'));
       // @todo: Cleaner sub request handling.
       $subrequest_url = $entity->urlInfo()->setOption('query', ['page' => $page])->toString(TRUE);
       $redirect_request = Request::create($subrequest_url->getGeneratedUrl(), 'GET', $request->query->all(), $request->cookies->all(), [], $request->server->all());
@@ -155,7 +172,7 @@ public function commentPermalink(Request $request, CommentInterface $comment) {
    *   The translated comment subject.
    */
   public function commentPermalinkTitle(CommentInterface $comment) {
-    return $this->entityManager()->getTranslationFromContext($comment)->label();
+    return $this->entityRepository->getTranslationFromContext($comment)->label();
   }
 
   /**
@@ -219,9 +236,9 @@ public function getReplyForm(Request $request, EntityInterface $entity, $field_n
       // $pid indicates that this is a reply to a comment.
       if ($pid) {
         // Load the parent comment.
-        $comment = $this->entityManager()->getStorage('comment')->load($pid);
+        $comment = $this->entityTypeManager()->getStorage('comment')->load($pid);
         // Display the parent comment.
-        $build['comment_parent'] = $this->entityManager()->getViewBuilder('comment')->view($comment);
+        $build['comment_parent'] = $this->entityTypeManager()->getViewBuilder('comment')->view($comment);
       }
 
       // The comment is in response to a entity.
@@ -231,7 +248,7 @@ public function getReplyForm(Request $request, EntityInterface $entity, $field_n
         $entity = clone $entity;
         $entity->{$field_name}->status = CommentItemInterface::HIDDEN;
         // Render array of the entity full view mode.
-        $build['commented_entity'] = $this->entityManager()->getViewBuilder($entity->getEntityTypeId())->view($entity, 'full');
+        $build['commented_entity'] = $this->entityTypeManager()->getViewBuilder($entity->getEntityTypeId())->view($entity, 'full');
         unset($build['commented_entity']['#cache']);
       }
     }
@@ -240,7 +257,7 @@ public function getReplyForm(Request $request, EntityInterface $entity, $field_n
     }
 
     // Show the actual reply box.
-    $comment = $this->entityManager()->getStorage('comment')->create([
+    $comment = $this->entityTypeManager()->getStorage('comment')->create([
       'entity_id' => $entity->id(),
       'pid' => $pid,
       'entity_type' => $entity->getEntityTypeId(),
@@ -292,7 +309,7 @@ public function replyFormAccess(EntityInterface $entity, $field_name, $pid = NUL
       $access = $access->andIf(AccessResult::allowedIfHasPermission($account, 'access comments'));
 
       // Load the parent comment.
-      $comment = $this->entityManager()->getStorage('comment')->load($pid);
+      $comment = $this->entityTypeManager()->getStorage('comment')->load($pid);
       // Check if the parent comment is published and belongs to the entity.
       $access = $access->andIf(AccessResult::allowedIf($comment && $comment->isPublished() && $comment->getCommentedEntityId() == $entity->id()));
       if ($comment) {
@@ -329,9 +346,9 @@ public function renderNewCommentsNodeLinks(Request $request) {
 
     $links = [];
     foreach ($nids as $nid) {
-      $node = $this->entityManager->getStorage('node')->load($nid);
+      $node = $this->entityTypeManager()->getStorage('node')->load($nid);
       $new = $this->commentManager->getCountNewComments($node);
-      $page_number = $this->entityManager()->getStorage('comment')
+      $page_number = $this->entityTypeManager()->getStorage('comment')
         ->getNewCommentPageNumber($node->{$field_name}->comment_count, $new, $node, $field_name);
       $query = $page_number ? ['page' => $page_number] : NULL;
       $links[$nid] = [
diff --git a/core/modules/config_translation/src/Controller/ConfigTranslationListController.php b/core/modules/config_translation/src/Controller/ConfigTranslationListController.php
index 3870131414..f8204ca1a8 100644
--- a/core/modules/config_translation/src/Controller/ConfigTranslationListController.php
+++ b/core/modules/config_translation/src/Controller/ConfigTranslationListController.php
@@ -63,7 +63,7 @@ public function listing($mapper_id) {
     // controller defined, use it. Other mappers, for examples the ones for
     // node_type and block, fallback to the generic configuration translation
     // list controller.
-    $build = $this->entityManager()
+    $build = $this->entityTypeManager()
       ->getHandler($entity_type, 'config_translation_list')
       ->setMapperDefinition($mapper_definition)
       ->render();
diff --git a/core/modules/contact/src/Controller/ContactController.php b/core/modules/contact/src/Controller/ContactController.php
index 6f9568f6d6..5bb3b2f142 100644
--- a/core/modules/contact/src/Controller/ContactController.php
+++ b/core/modules/contact/src/Controller/ContactController.php
@@ -59,7 +59,7 @@ public function contactSitePage(ContactFormInterface $contact_form = NULL) {
 
     // Use the default form if no form has been passed.
     if (empty($contact_form)) {
-      $contact_form = $this->entityManager()
+      $contact_form = $this->entityTypeManager()
         ->getStorage('contact_form')
         ->load($config->get('default_form'));
       // If there are no forms, do not display the form.
@@ -76,7 +76,7 @@ public function contactSitePage(ContactFormInterface $contact_form = NULL) {
       }
     }
 
-    $message = $this->entityManager()
+    $message = $this->entityTypeManager()
       ->getStorage('contact_message')
       ->create([
         'contact_form' => $contact_form->id(),
@@ -109,7 +109,7 @@ public function contactPersonalPage(UserInterface $user) {
       throw new NotFoundHttpException();
     }
 
-    $message = $this->entityManager()->getStorage('contact_message')->create([
+    $message = $this->entityTypeManager()->getStorage('contact_message')->create([
       'contact_form' => 'personal',
       'recipient' => $user->id(),
     ]);
diff --git a/core/modules/content_translation/src/Controller/ContentTranslationController.php b/core/modules/content_translation/src/Controller/ContentTranslationController.php
index 3f5891b73a..2c1632d46a 100644
--- a/core/modules/content_translation/src/Controller/ContentTranslationController.php
+++ b/core/modules/content_translation/src/Controller/ContentTranslationController.php
@@ -7,6 +7,7 @@
 use Drupal\Core\Cache\CacheableMetadata;
 use Drupal\Core\Controller\ControllerBase;
 use Drupal\Core\Entity\ContentEntityInterface;
+use Drupal\Core\Entity\EntityFieldManagerInterface;
 use Drupal\Core\Language\LanguageInterface;
 use Drupal\Core\Routing\RouteMatchInterface;
 use Drupal\Core\Url;
@@ -24,21 +25,34 @@ class ContentTranslationController extends ControllerBase {
    */
   protected $manager;
 
+  /**
+   * The entity field manager.
+   *
+   * @var \Drupal\Core\Entity\EntityFieldManagerInterface
+   */
+  protected $entityFieldManager;
+
   /**
    * Initializes a content translation controller.
    *
    * @param \Drupal\content_translation\ContentTranslationManagerInterface $manager
    *   A content translation manager instance.
+   * @param \Drupal\Core\Entity\EntityFieldManagerInterface $entity_field_manager
+   *   The entity field manager service.
    */
-  public function __construct(ContentTranslationManagerInterface $manager) {
+  public function __construct(ContentTranslationManagerInterface $manager, EntityFieldManagerInterface $entity_field_manager) {
     $this->manager = $manager;
+    $this->entityFieldManager = $entity_field_manager;
   }
 
   /**
    * {@inheritdoc}
    */
   public static function create(ContainerInterface $container) {
-    return new static($container->get('content_translation.manager'));
+    return new static(
+      $container->get('content_translation.manager'),
+      $container->get('entity_field.manager')
+    );
   }
 
   /**
@@ -62,7 +76,7 @@ public function prepareTranslation(ContentEntityInterface $entity, LanguageInter
     }
 
     /** @var \Drupal\user\UserInterface $user */
-    $user = $this->entityManager()->getStorage('user')->load($this->currentUser()->id());
+    $user = $this->entityTypeManager()->getStorage('user')->load($this->currentUser()->id());
     $metadata = $this->manager->getTranslationMetadata($target_translation);
 
     // Update the translation author to current user, as well the translation
@@ -85,7 +99,7 @@ public function overview(RouteMatchInterface $route_match, $entity_type_id = NUL
     /** @var \Drupal\Core\Entity\ContentEntityInterface $entity */
     $entity = $route_match->getParameter($entity_type_id);
     $account = $this->currentUser();
-    $handler = $this->entityManager()->getHandler($entity_type_id, 'translation');
+    $handler = $this->entityTypeManager()->getHandler($entity_type_id, 'translation');
     $manager = $this->manager;
     $entity_type = $entity->getEntityType();
     $use_latest_revisions = $entity_type->isRevisionable() && ContentTranslationManager::isPendingRevisionSupportEnabled($entity_type_id, $entity->bundle());
@@ -108,7 +122,7 @@ public function overview(RouteMatchInterface $route_match, $entity_type_id = NUL
     if ($this->languageManager()->isMultilingual()) {
       // Determine whether the current entity is translatable.
       $translatable = FALSE;
-      foreach ($this->entityManager->getFieldDefinitions($entity_type_id, $entity->bundle()) as $instance) {
+      foreach ($this->entityFieldManager->getFieldDefinitions($entity_type_id, $entity->bundle()) as $instance) {
         if ($instance->isTranslatable()) {
           $translatable = TRUE;
           break;
diff --git a/core/modules/dblog/src/Controller/DbLogController.php b/core/modules/dblog/src/Controller/DbLogController.php
index 9fe2922ece..71f4e24c4b 100644
--- a/core/modules/dblog/src/Controller/DbLogController.php
+++ b/core/modules/dblog/src/Controller/DbLogController.php
@@ -8,6 +8,7 @@
 use Drupal\Core\Controller\ControllerBase;
 use Drupal\Core\Database\Connection;
 use Drupal\Core\Datetime\DateFormatterInterface;
+use Drupal\Core\Entity\EntityTypeManagerInterface;
 use Drupal\Core\Extension\ModuleHandlerInterface;
 use Drupal\Core\Form\FormBuilderInterface;
 use Drupal\Core\Logger\RfcLogLevel;
@@ -63,7 +64,8 @@ public static function create(ContainerInterface $container) {
       $container->get('database'),
       $container->get('module_handler'),
       $container->get('date.formatter'),
-      $container->get('form_builder')
+      $container->get('form_builder'),
+      $container->get('entity_type.manager')
     );
   }
 
@@ -78,13 +80,15 @@ public static function create(ContainerInterface $container) {
    *   The date formatter service.
    * @param \Drupal\Core\Form\FormBuilderInterface $form_builder
    *   The form builder service.
+   * @param \Drupal\Core\Entity\EntityTypeManagerInterface
+   *   The entity type manager interface.
    */
-  public function __construct(Connection $database, ModuleHandlerInterface $module_handler, DateFormatterInterface $date_formatter, FormBuilderInterface $form_builder) {
+  public function __construct(Connection $database, ModuleHandlerInterface $module_handler, DateFormatterInterface $date_formatter, FormBuilderInterface $form_builder, EntityTypeManagerInterface $entity_type_manager) {
     $this->database = $database;
     $this->moduleHandler = $module_handler;
     $this->dateFormatter = $date_formatter;
     $this->formBuilder = $form_builder;
-    $this->userStorage = $this->entityManager()->getStorage('user');
+    $this->userStorage = $entity_type_manager->getStorage('user');
   }
 
   /**
diff --git a/core/modules/editor/src/EditorController.php b/core/modules/editor/src/EditorController.php
index 995ff7c6c5..81441772c0 100644
--- a/core/modules/editor/src/EditorController.php
+++ b/core/modules/editor/src/EditorController.php
@@ -70,7 +70,7 @@ public function filterXss(Request $request, FilterFormatInterface $filter_format
     $original_format_id = $request->request->get('original_format_id');
     $original_format = NULL;
     if (isset($original_format_id)) {
-      $original_format = $this->entityManager()
+      $original_format = $this->entityTypeManager()
         ->getStorage('filter_format')
         ->load($original_format_id);
     }
diff --git a/core/modules/field_ui/src/Controller/EntityDisplayModeController.php b/core/modules/field_ui/src/Controller/EntityDisplayModeController.php
index b4a608acd5..a433b2ea31 100644
--- a/core/modules/field_ui/src/Controller/EntityDisplayModeController.php
+++ b/core/modules/field_ui/src/Controller/EntityDisplayModeController.php
@@ -18,7 +18,7 @@ class EntityDisplayModeController extends ControllerBase {
    */
   public function viewModeTypeSelection() {
     $entity_types = [];
-    foreach ($this->entityManager()->getDefinitions() as $entity_type_id => $entity_type) {
+    foreach ($this->entityTypeManager()->getDefinitions() as $entity_type_id => $entity_type) {
       if ($entity_type->get('field_ui_base_route') && $entity_type->hasViewBuilderClass()) {
         $entity_types[$entity_type_id] = [
           'title' => $entity_type->getLabel(),
@@ -41,7 +41,7 @@ public function viewModeTypeSelection() {
    */
   public function formModeTypeSelection() {
     $entity_types = [];
-    foreach ($this->entityManager()->getDefinitions() as $entity_type_id => $entity_type) {
+    foreach ($this->entityTypeManager()->getDefinitions() as $entity_type_id => $entity_type) {
       if ($entity_type->get('field_ui_base_route') && $entity_type->hasFormClasses()) {
         $entity_types[$entity_type_id] = [
           'title' => $entity_type->getLabel(),
diff --git a/core/modules/field_ui/src/Controller/FieldConfigListController.php b/core/modules/field_ui/src/Controller/FieldConfigListController.php
index 5866405a83..ecfb44964b 100644
--- a/core/modules/field_ui/src/Controller/FieldConfigListController.php
+++ b/core/modules/field_ui/src/Controller/FieldConfigListController.php
@@ -25,7 +25,7 @@ class FieldConfigListController extends EntityListController {
    *   \Drupal\Core\Render\RendererInterface::render().
    */
   public function listing($entity_type_id = NULL, $bundle = NULL, RouteMatchInterface $route_match = NULL) {
-    return $this->entityManager()->getListBuilder('field_config')->render($entity_type_id, $bundle);
+    return $this->entityTypeManager()->getListBuilder('field_config')->render($entity_type_id, $bundle);
   }
 
 }
diff --git a/core/modules/image/src/Controller/QuickEditImageController.php b/core/modules/image/src/Controller/QuickEditImageController.php
index 5fc28ba2eb..b45c7e63cf 100644
--- a/core/modules/image/src/Controller/QuickEditImageController.php
+++ b/core/modules/image/src/Controller/QuickEditImageController.php
@@ -5,6 +5,7 @@
 use Drupal\Core\Cache\CacheableJsonResponse;
 use Drupal\Core\Controller\ControllerBase;
 use Drupal\Core\Entity\ContentEntityInterface;
+use Drupal\Core\Entity\EntityDisplayRepositoryInterface;
 use Drupal\Core\Entity\EntityInterface;
 use Drupal\Core\Image\ImageFactory;
 use Drupal\Core\Render\Element\StatusMessages;
@@ -41,6 +42,13 @@ class QuickEditImageController extends ControllerBase {
    */
   protected $imageFactory;
 
+  /**
+   * The entity display repository service.
+   *
+   * @var \Drupal\Core\Entity\EntityDisplayRepositoryInterface
+   */
+  protected $entityDisplayRepository;
+
   /**
    * Constructs a new QuickEditImageController.
    *
@@ -50,11 +58,14 @@ class QuickEditImageController extends ControllerBase {
    *   The image factory.
    * @param \Drupal\Core\TempStore\PrivateTempStoreFactory $temp_store_factory
    *   The tempstore factory.
+   * @param \Drupal\Core\Entity\EntityDisplayRepositoryInterface $entity_display_repository
+   *   The entity display repository service.
    */
-  public function __construct(RendererInterface $renderer, ImageFactory $image_factory, PrivateTempStoreFactory $temp_store_factory) {
+  public function __construct(RendererInterface $renderer, ImageFactory $image_factory, PrivateTempStoreFactory $temp_store_factory, EntityDisplayRepositoryInterface $entity_display_repository) {
     $this->renderer = $renderer;
     $this->imageFactory = $image_factory;
     $this->tempStore = $temp_store_factory->get('quickedit');
+    $this->entityDisplayRepository = $entity_display_repository;
   }
 
   /**
@@ -64,7 +75,8 @@ public static function create(ContainerInterface $container) {
     return new static(
       $container->get('renderer'),
       $container->get('image.factory'),
-      $container->get('tempstore.private')
+      $container->get('tempstore.private'),
+      $container->get('entity_display.repository')
     );
   }
 
@@ -115,7 +127,7 @@ public function upload(EntityInterface $entity, $field_name, $langcode, $view_mo
       $entity->$field_name->setValue($value);
 
       // Render the new image using the correct formatter settings.
-      $entity_view_mode_ids = array_keys($this->entityManager()->getViewModes($entity->getEntityTypeId()));
+      $entity_view_mode_ids = array_keys($this->entityDisplayRepository->getViewModes($entity->getEntityTypeId()));
       if (in_array($view_mode_id, $entity_view_mode_ids, TRUE)) {
         $output = $entity->$field_name->view($view_mode_id);
       }
diff --git a/core/modules/node/src/Controller/NodeController.php b/core/modules/node/src/Controller/NodeController.php
index 704bf51f88..e631a9fcbe 100644
--- a/core/modules/node/src/Controller/NodeController.php
+++ b/core/modules/node/src/Controller/NodeController.php
@@ -6,6 +6,7 @@
 use Drupal\Core\Controller\ControllerBase;
 use Drupal\Core\Datetime\DateFormatterInterface;
 use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
+use Drupal\Core\Entity\EntityRepositoryInterface;
 use Drupal\Core\Render\RendererInterface;
 use Drupal\Core\Url;
 use Drupal\node\NodeStorageInterface;
@@ -32,6 +33,13 @@ class NodeController extends ControllerBase implements ContainerInjectionInterfa
    */
   protected $renderer;
 
+  /**
+   * The entity repository service.
+   *
+   * @var \Drupal\Core\Entity\EntityRepositoryInterface
+   */
+  protected $entityRepository;
+
   /**
    * Constructs a NodeController object.
    *
@@ -40,9 +48,10 @@ class NodeController extends ControllerBase implements ContainerInjectionInterfa
    * @param \Drupal\Core\Render\RendererInterface $renderer
    *   The renderer service.
    */
-  public function __construct(DateFormatterInterface $date_formatter, RendererInterface $renderer) {
+  public function __construct(DateFormatterInterface $date_formatter, RendererInterface $renderer, EntityRepositoryInterface $entity_repository) {
     $this->dateFormatter = $date_formatter;
     $this->renderer = $renderer;
+    $this->entityRepository = $entity_repository;
   }
 
   /**
@@ -51,7 +60,8 @@ public function __construct(DateFormatterInterface $date_formatter, RendererInte
   public static function create(ContainerInterface $container) {
     return new static(
       $container->get('date.formatter'),
-      $container->get('renderer')
+      $container->get('renderer'),
+      $container->get('entity.repository')
     );
   }
 
@@ -70,15 +80,15 @@ public function addPage() {
     $build = [
       '#theme' => 'node_add_list',
       '#cache' => [
-        'tags' => $this->entityManager()->getDefinition('node_type')->getListCacheTags(),
+        'tags' => $this->entityTypeManager()->getDefinition('node_type')->getListCacheTags(),
       ],
     ];
 
     $content = [];
 
     // Only use node types the user has access to.
-    foreach ($this->entityManager()->getStorage('node_type')->loadMultiple() as $type) {
-      $access = $this->entityManager()->getAccessControlHandler('node')->createAccess($type->id(), NULL, [], TRUE);
+    foreach ($this->entityTypeManager()->getStorage('node_type')->loadMultiple() as $type) {
+      $access = $this->entityTypeManager()->getAccessControlHandler('node')->createAccess($type->id(), NULL, [], TRUE);
       if ($access->isAllowed()) {
         $content[$type->id()] = $type;
       }
@@ -106,7 +116,7 @@ public function addPage() {
    *   A node submission form.
    */
   public function add(NodeTypeInterface $node_type) {
-    $node = $this->entityManager()->getStorage('node')->create([
+    $node = $this->entityTypeManager()->getStorage('node')->create([
       'type' => $node_type->id(),
     ]);
 
@@ -125,9 +135,9 @@ public function add(NodeTypeInterface $node_type) {
    *   An array suitable for \Drupal\Core\Render\RendererInterface::render().
    */
   public function revisionShow($node_revision) {
-    $node = $this->entityManager()->getStorage('node')->loadRevision($node_revision);
-    $node = $this->entityManager()->getTranslationFromContext($node);
-    $node_view_controller = new NodeViewController($this->entityManager, $this->renderer, $this->currentUser());
+    $node = $this->entityTypeManager()->getStorage('node')->loadRevision($node_revision);
+    $node = $this->entityRepository->getTranslationFromContext($node);
+    $node_view_controller = new NodeViewController($this->entityTypeManager(), $this->renderer, $this->currentUser());
     $page = $node_view_controller->view($node);
     unset($page['nodes'][$node->id()]['#cache']);
     return $page;
@@ -143,7 +153,7 @@ public function revisionShow($node_revision) {
    *   The page title.
    */
   public function revisionPageTitle($node_revision) {
-    $node = $this->entityManager()->getStorage('node')->loadRevision($node_revision);
+    $node = $this->entityTypeManager()->getStorage('node')->loadRevision($node_revision);
     return $this->t('Revision of %title from %date', ['%title' => $node->label(), '%date' => format_date($node->getRevisionCreationTime())]);
   }
 
@@ -162,7 +172,7 @@ public function revisionOverview(NodeInterface $node) {
     $langname = $node->language()->getName();
     $languages = $node->getTranslationLanguages();
     $has_translations = (count($languages) > 1);
-    $node_storage = $this->entityManager()->getStorage('node');
+    $node_storage = $this->entityTypeManager()->getStorage('node');
     $type = $node->getType();
 
     $build['#title'] = $has_translations ? $this->t('@langname revisions for %title', ['@langname' => $langname, '%title' => $node->label()]) : $this->t('Revisions for %title', ['%title' => $node->label()]);
diff --git a/core/modules/node/src/Controller/NodePreviewController.php b/core/modules/node/src/Controller/NodePreviewController.php
index 1a1c3cac50..e970c5109d 100644
--- a/core/modules/node/src/Controller/NodePreviewController.php
+++ b/core/modules/node/src/Controller/NodePreviewController.php
@@ -35,7 +35,7 @@ public function view(EntityInterface $node_preview, $view_mode_id = 'full', $lan
    *   The page title.
    */
   public function title(EntityInterface $node_preview) {
-    return $this->entityManager->getTranslationFromContext($node_preview)->label();
+    return $this->entityTypeManager->getTranslationFromContext($node_preview)->label();
   }
 
 }
diff --git a/core/modules/quickedit/src/QuickEditController.php b/core/modules/quickedit/src/QuickEditController.php
index 3bed196661..bc81769cdb 100644
--- a/core/modules/quickedit/src/QuickEditController.php
+++ b/core/modules/quickedit/src/QuickEditController.php
@@ -3,6 +3,7 @@
 namespace Drupal\quickedit;
 
 use Drupal\Core\Controller\ControllerBase;
+use Drupal\Core\Entity\EntityRepositoryInterface;
 use Drupal\Core\Form\FormState;
 use Drupal\Core\Render\RendererInterface;
 use Drupal\Core\TempStore\PrivateTempStoreFactory;
@@ -12,6 +13,7 @@
 use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;
 use Drupal\Core\Ajax\AjaxResponse;
 use Drupal\Core\Entity\EntityInterface;
+use Drupal\Core\Entity\EntityDisplayRepositoryInterface;
 use Drupal\quickedit\Ajax\FieldFormCommand;
 use Drupal\quickedit\Ajax\FieldFormSavedCommand;
 use Drupal\quickedit\Ajax\FieldFormValidationErrorsCommand;
@@ -50,6 +52,20 @@ class QuickEditController extends ControllerBase {
    */
   protected $renderer;
 
+  /**
+   * The entity display repository service.
+   *
+   * @var \Drupal\Core\Entity\EntityDisplayRepositoryInterface
+   */
+  protected $entityDisplayRepository;
+
+  /**
+   * The entity repository.
+   *
+   * @var \Drupal\Core\Entity\EntityRepositoryInterface
+   */
+  protected $entityRepository;
+
   /**
    * Constructs a new QuickEditController.
    *
@@ -61,12 +77,18 @@ class QuickEditController extends ControllerBase {
    *   The in-place editor selector.
    * @param \Drupal\Core\Render\RendererInterface $renderer
    *   The renderer.
+   * @param \Drupal\Core\Entity\EntityDisplayRepositoryInterface $entity_display_repository
+   *   The entity display repository service.
+   * @param \Drupal\Core\Entity\EntityRepositoryInterface $entity_repository
+   *   The entity repository.
    */
-  public function __construct(PrivateTempStoreFactory $temp_store_factory, MetadataGeneratorInterface $metadata_generator, EditorSelectorInterface $editor_selector, RendererInterface $renderer) {
+  public function __construct(PrivateTempStoreFactory $temp_store_factory, MetadataGeneratorInterface $metadata_generator, EditorSelectorInterface $editor_selector, RendererInterface $renderer, EntityDisplayRepositoryInterface $entity_display_repository, EntityRepositoryInterface $entity_repository) {
     $this->tempStoreFactory = $temp_store_factory;
     $this->metadataGenerator = $metadata_generator;
     $this->editorSelector = $editor_selector;
     $this->renderer = $renderer;
+    $this->entityDisplayRepository = $entity_display_repository;
+    $this->entityRepository = $entity_repository;
   }
 
   /**
@@ -77,7 +99,9 @@ public static function create(ContainerInterface $container) {
       $container->get('tempstore.private'),
       $container->get('quickedit.metadata.generator'),
       $container->get('quickedit.editor.selector'),
-      $container->get('renderer')
+      $container->get('renderer'),
+      $container->get('entity_display.repository'),
+      $container->get('entity.repository')
     );
   }
 
@@ -103,10 +127,10 @@ public function metadata(Request $request) {
       list($entity_type, $entity_id, $field_name, $langcode, $view_mode) = explode('/', $field);
 
       // Load the entity.
-      if (!$entity_type || !$this->entityManager()->getDefinition($entity_type)) {
+      if (!$entity_type || !$this->entityTypeManager()->getDefinition($entity_type)) {
         throw new NotFoundHttpException();
       }
-      $entity = $this->entityManager()->getStorage($entity_type)->load($entity_id);
+      $entity = $this->entityTypeManager()->getStorage($entity_type)->load($entity_id);
       if (!$entity) {
         throw new NotFoundHttpException();
       }
@@ -256,9 +280,9 @@ public function fieldForm(EntityInterface $entity, $field_name, $langcode, $view
    * @see hook_quickedit_render_field()
    */
   protected function renderField(EntityInterface $entity, $field_name, $langcode, $view_mode_id) {
-    $entity_view_mode_ids = array_keys($this->entityManager()->getViewModes($entity->getEntityTypeId()));
+    $entity_view_mode_ids = array_keys($this->entityDisplayRepository->getViewModes($entity->getEntityTypeId()));
     if (in_array($view_mode_id, $entity_view_mode_ids)) {
-      $entity = \Drupal::entityManager()->getTranslationFromContext($entity, $langcode);
+      $entity = $this->entityRepository->getTranslationFromContext($entity, $langcode);
       $output = $entity->get($field_name)->view($view_mode_id);
     }
     else {
diff --git a/core/modules/shortcut/src/Controller/ShortcutController.php b/core/modules/shortcut/src/Controller/ShortcutController.php
index dbb24e582e..d70cd7e07f 100644
--- a/core/modules/shortcut/src/Controller/ShortcutController.php
+++ b/core/modules/shortcut/src/Controller/ShortcutController.php
@@ -21,7 +21,7 @@ class ShortcutController extends ControllerBase {
    *   The shortcut add form.
    */
   public function addForm(ShortcutSetInterface $shortcut_set) {
-    $shortcut = $this->entityManager()->getStorage('shortcut')->create(['shortcut_set' => $shortcut_set->id()]);
+    $shortcut = $this->entityTypeManager()->getStorage('shortcut')->create(['shortcut_set' => $shortcut_set->id()]);
     return $this->entityFormBuilder()->getForm($shortcut, 'add');
   }
 
diff --git a/core/modules/shortcut/src/Controller/ShortcutSetController.php b/core/modules/shortcut/src/Controller/ShortcutSetController.php
index 541d43796c..a0ac48bdf9 100644
--- a/core/modules/shortcut/src/Controller/ShortcutSetController.php
+++ b/core/modules/shortcut/src/Controller/ShortcutSetController.php
@@ -55,7 +55,7 @@ public function addShortcutLinkInline(ShortcutSetInterface $shortcut_set, Reques
     $link = $request->query->get('link');
     $name = $request->query->get('name');
     if (parse_url($link, PHP_URL_SCHEME) === NULL && $this->pathValidator->isValid($link)) {
-      $shortcut = $this->entityManager()->getStorage('shortcut')->create([
+      $shortcut = $this->entityTypeManager()->getStorage('shortcut')->create([
         'title' => $name,
         'shortcut_set' => $shortcut_set->id(),
         'link' => [
diff --git a/core/modules/system/tests/modules/entity_test/src/Controller/EntityTestController.php b/core/modules/system/tests/modules/entity_test/src/Controller/EntityTestController.php
index fa69e783d0..e9f0f8a689 100644
--- a/core/modules/system/tests/modules/entity_test/src/Controller/EntityTestController.php
+++ b/core/modules/system/tests/modules/entity_test/src/Controller/EntityTestController.php
@@ -34,7 +34,7 @@ public function testAdmin() {
    */
   public function listReferencingEntities($entity_reference_field_name, $referenced_entity_type, $referenced_entity_id) {
     // Early return if the referenced entity does not exist (or is deleted).
-    $referenced_entity = $this->entityManager()
+    $referenced_entity = $this->entityTypeManager()
       ->getStorage($referenced_entity_type)
       ->load($referenced_entity_id);
     if ($referenced_entity === NULL) {
@@ -43,10 +43,10 @@ public function listReferencingEntities($entity_reference_field_name, $reference
 
     $query = $this->entityTypeManager()->getStorage('entity_test')->getQuery()
       ->condition($entity_reference_field_name . '.target_id', $referenced_entity_id);
-    $entities = $this->entityManager()
+    $entities = $this->entityTypeManager()
       ->getStorage('entity_test')
       ->loadMultiple($query->execute());
-    return $this->entityManager()
+    return $this->entityTypeManager()
       ->getViewBuilder('entity_test')
       ->viewMultiple($entities, 'full');
   }
@@ -61,7 +61,7 @@ public function listReferencingEntities($entity_reference_field_name, $reference
    *   A renderable array.
    */
   public function listEntitiesAlphabetically($entity_type_id) {
-    $entity_type_definition = $this->entityManager()->getDefinition($entity_type_id);
+    $entity_type_definition = $this->entityTypeManager()->getDefinition($entity_type_id);
     $query = $this->entityTypeManager()->getStorage($entity_type_id)->getQuery();
 
     // Sort by label field, if any.
@@ -69,7 +69,7 @@ public function listEntitiesAlphabetically($entity_type_id) {
       $query->sort($label_field);
     }
 
-    $entities = $this->entityManager()
+    $entities = $this->entityTypeManager()
       ->getStorage($entity_type_id)
       ->loadMultiple($query->execute());
 
@@ -109,7 +109,7 @@ public function listEntitiesAlphabetically($entity_type_id) {
    *   A renderable array.
    */
   public function listEntitiesEmpty($entity_type_id) {
-    $entity_type_definition = $this->entityManager()->getDefinition($entity_type_id);
+    $entity_type_definition = $this->entityTypeManager()->getDefinition($entity_type_id);
     return [
       '#theme' => 'item_list',
       '#items' => [],
diff --git a/core/modules/system/tests/modules/form_test/src/Controller/FormTestController.php b/core/modules/system/tests/modules/form_test/src/Controller/FormTestController.php
index b571c2da24..9a0bc62c85 100644
--- a/core/modules/system/tests/modules/form_test/src/Controller/FormTestController.php
+++ b/core/modules/system/tests/modules/form_test/src/Controller/FormTestController.php
@@ -26,7 +26,7 @@ public function twoFormInstances() {
       'type' => 'page',
       'langcode' => LanguageInterface::LANGCODE_NOT_SPECIFIED,
     ];
-    $node1 = $this->entityManager()->getStorage('node')->create($values);
+    $node1 = $this->entityTypeManager()->getStorage('node')->create($values);
     $node2 = clone($node1);
     $return['node_form_1'] = $this->entityFormBuilder()->getForm($node1);
     $return['node_form_2'] = $this->entityFormBuilder()->getForm($node2);
diff --git a/core/modules/taxonomy/src/Controller/TaxonomyController.php b/core/modules/taxonomy/src/Controller/TaxonomyController.php
index 27b1ec0c86..3c04339009 100644
--- a/core/modules/taxonomy/src/Controller/TaxonomyController.php
+++ b/core/modules/taxonomy/src/Controller/TaxonomyController.php
@@ -22,7 +22,7 @@ class TaxonomyController extends ControllerBase {
    *   The taxonomy term add form.
    */
   public function addForm(VocabularyInterface $taxonomy_vocabulary) {
-    $term = $this->entityManager()->getStorage('taxonomy_term')->create(['vid' => $taxonomy_vocabulary->id()]);
+    $term = $this->entityTypeManager()->getStorage('taxonomy_term')->create(['vid' => $taxonomy_vocabulary->id()]);
     return $this->entityFormBuilder()->getForm($term);
   }
 
diff --git a/core/modules/views_ui/src/Controller/ViewsUIController.php b/core/modules/views_ui/src/Controller/ViewsUIController.php
index 9794762074..fe3d1595bc 100644
--- a/core/modules/views_ui/src/Controller/ViewsUIController.php
+++ b/core/modules/views_ui/src/Controller/ViewsUIController.php
@@ -54,7 +54,7 @@ public static function create(ContainerInterface $container) {
    *   The Views fields report page.
    */
   public function reportFields() {
-    $views = $this->entityManager()->getStorage('view')->loadMultiple();
+    $views = $this->entityTypeManager()->getStorage('view')->loadMultiple();
 
     // Fetch all fieldapi fields which are used in views
     // Therefore search in all views, displays and handler-types.
@@ -160,7 +160,7 @@ public function ajaxOperation(ViewEntityInterface $view, $op, Request $request)
 
     // If the request is via AJAX, return the rendered list as JSON.
     if ($request->request->get('js')) {
-      $list = $this->entityManager()->getListBuilder('view')->render();
+      $list = $this->entityTypeManager()->getListBuilder('view')->render();
       $response = new AjaxResponse();
       $response->addCommand(new ReplaceCommand('#views-entity-list', $list));
       return $response;
@@ -183,7 +183,7 @@ public function autocompleteTag(Request $request) {
     $matches = [];
     $string = $request->query->get('q');
     // Get matches from default views.
-    $views = $this->entityManager()->getStorage('view')->loadMultiple();
+    $views = $this->entityTypeManager()->getStorage('view')->loadMultiple();
     // Keep track of previously processed tags so they can be skipped.
     $tags = [];
     foreach ($views as $view) {

diff --git a/core/lib/Drupal/Core/Entity/Controller/EntityViewController.php b/core/lib/Drupal/Core/Entity/Controller/EntityViewController.php
index 7922ef40f1..3024029f5b 100644
--- a/core/lib/Drupal/Core/Entity/Controller/EntityViewController.php
+++ b/core/lib/Drupal/Core/Entity/Controller/EntityViewController.php
@@ -4,8 +4,8 @@
 
 use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
 use Drupal\Core\Entity\EntityInterface;
+use Drupal\Core\Entity\EntityTypeManagerInterface;
 use Drupal\Core\Entity\FieldableEntityInterface;
-use Drupal\Core\Entity\EntityManagerInterface;
 use Drupal\Core\Render\RendererInterface;
 use Symfony\Component\DependencyInjection\ContainerInterface;
 
@@ -15,11 +15,11 @@
 class EntityViewController implements ContainerInjectionInterface {
 
   /**
    * The entity manager
    *
    * @var \Drupal\Core\Entity\EntityManagerInterface
    */
-  protected $entityManager;
+  protected $entityTypeManager;
 
   /**
    * The renderer service.
@@ -31,13 +31,13 @@ class EntityViewController implements ContainerInjectionInterface {
   /**
    * Creates an EntityViewController object.
    *
    * @param \Drupal\Core\Entity\EntityManagerInterface $entity_manager
    *   The entity manager.
    * @param \Drupal\Core\Render\RendererInterface $renderer
    *   The renderer service.
    */
-  public function __construct(EntityManagerInterface $entity_manager, RendererInterface $renderer) {
-    $this->entityManager = $entity_manager;
+  public function __construct(EntityTypeManagerInterface $entity_type_manager, RendererInterface $renderer) {
+    $this->entityTypeManager = $entity_type_manager;
     $this->renderer = $renderer;
   }
 
@@ -46,7 +46,7 @@ public function __construct(EntityManagerInterface $entity_manager, RendererInte
    */
   public static function create(ContainerInterface $container) {
     return new static(
-      $container->get('entity.manager'),
+      $container->get('entity_type.manager'),
       $container->get('renderer')
     );
   }
@@ -92,7 +92,7 @@ public function buildTitle(array $page) {
    *   \Drupal\Core\Render\RendererInterface::render().
    */
   public function view(EntityInterface $_entity, $view_mode = 'full') {
-    $page = $this->entityManager
+    $page = $this->entityTypeManager
       ->getViewBuilder($_entity->getEntityTypeId())
       ->view($_entity, $view_mode);
 
@@ -15,11 +15,11 @@
 
   /**
-   * The entity manager
+   * The entity type manager.
    *
    * @var \Drupal\Core\Entity\EntityManagerInterface
@@ -31,13 +31,13 @@ class EntityViewController implements ContainerInjectionInterface {
    * Creates an EntityViewController object.
    *
-   * @param \Drupal\Core\Entity\EntityManagerInterface $entity_manager
-   *   The entity manager.
+   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
+   *   The entity type manager.
    * @param \Drupal\Core\Render\RendererInterface $renderer
    *   The renderer service.
diff --git a/core/modules/node/src/Controller/NodeViewController.php b/core/modules/node/src/Controller/NodeViewController.php
index b8aa1e5a97..e523442b2b 100644
--- a/core/modules/node/src/Controller/NodeViewController.php
+++ b/core/modules/node/src/Controller/NodeViewController.php
@@ -4,7 +4,8 @@
 
 use Drupal\Core\Entity\EntityInterface;
 use Drupal\Core\Entity\Controller\EntityViewController;
-use Drupal\Core\Entity\EntityManagerInterface;
+use Drupal\Core\Entity\EntityRepositoryInterface;
+use Drupal\Core\Entity\EntityTypeManagerInterface;
 use Drupal\Core\Render\RendererInterface;
 use Drupal\Core\Session\AccountInterface;
 use Symfony\Component\DependencyInjection\ContainerInterface;
@@ -21,20 +22,23 @@ class NodeViewController extends EntityViewController {
    */
   protected $currentUser;
 
+  protected $entityRepository;
+
   /**
    * Creates an NodeViewController object.
    *
    * @param \Drupal\Core\Entity\EntityManagerInterface $entity_manager
    *   The entity manager.
    * @param \Drupal\Core\Render\RendererInterface $renderer
    *   The renderer service.
    * @param \Drupal\Core\Session\AccountInterface $current_user
    *   The current user. For backwards compatibility this is optional, however
    *   this will be removed before Drupal 9.0.0.
    */
-  public function __construct(EntityManagerInterface $entity_manager, RendererInterface $renderer, AccountInterface $current_user = NULL) {
-    parent::__construct($entity_manager, $renderer);
+  public function __construct(EntityTypeManagerInterface $entity_type_manager, RendererInterface $renderer, AccountInterface $current_user = NULL, EntityRepositoryInterface $entity_repository = NULL) {
+    parent::__construct($entity_type_manager, $renderer);
     $this->currentUser = $current_user ?: \Drupal::currentUser();
+    $this->entityRepository = $entity_repository ?: \Drupal::service('entity.repository');
   }
 
   /**
@@ -42,9 +46,10 @@ public function __construct(EntityManagerInterface $entity_manager, RendererInte
    */
   public static function create(ContainerInterface $container) {
     return new static(
-      $container->get('entity.manager'),
+      $container->get('entity_type.manager'),
       $container->get('renderer'),
-      $container->get('current_user')
+      $container->get('current_user'),
+      $container->get('entity.repository')
     );
   }
 
@@ -106,7 +111,7 @@ public function view(EntityInterface $node, $view_mode = 'full', $langcode = NUL
    *   The page title.
    */
   public function title(EntityInterface $node) {
-    return $this->entityManager->getTranslationFromContext($node)->label();
+    return $this->entityRepository->getTranslationFromContext($node)->label();
   }
 
 }
@@ -21,20 +22,23 @@ class NodeViewController extends EntityViewController {
    * Creates an NodeViewController object.
    *
-   * @param \Drupal\Core\Entity\EntityManagerInterface $entity_manager
-   *   The entity manager.
+   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
+   *   The entity type manager.
    * @param \Drupal\Core\Render\RendererInterface $renderer
    *   The renderer service.